Documentation
¶
Overview ¶
Package ffookies provides a quick way to read cookies from a firefox browser profile.
Index ¶
- Variables
- func Jar(u *url.URL, cookies ...*http.Cookie) (http.CookieJar, error)
- func Read(profile, host string) ([]*http.Cookie, error)
- func ReadContext(ctx context.Context, profile, host string) ([]*http.Cookie, error)
- func ReadFile(file, host string) ([]*http.Cookie, error)
- func ReadFileContext(ctx context.Context, file, host string) ([]*http.Cookie, error)
- func ReadJar(profile, urlstr string) (http.CookieJar, error)
- func ReadJarContext(ctx context.Context, profile, urlstr string) (http.CookieJar, error)
- func ReadJarFiltered(profile, urlstr string, f func(*http.Cookie) bool) (http.CookieJar, error)
- func ReadJarFilteredContext(ctx context.Context, profile, urlstr string, f func(*http.Cookie) bool) (http.CookieJar, error)
Constants ¶
This section is empty.
Variables ¶
var DefaultOpenParams = "?nolock=1&immutable=1&mode=ro"
DefaultOpenParams are the default open parameters to use.
Functions ¶
func ReadContext ¶
ReadContext reads the cookies for the provided Firefox profile name, or the default Firefox profile.
func ReadFileContext ¶
ReadFileContext reads the cookies from the provided sqlite3 file on disk.
func ReadJar ¶
ReadJar reads the cookies from the provided sqlite3 file for the provided url into a cookie jar usable with http.Client.
func ReadJarContext ¶
ReadJarContext reads the cookies from the provided sqlite3 file for the provided url into a cookie jar usable with http.Client.
func ReadJarFiltered ¶
ReadJarFiltered reads the cookies from the provided sqlite3 file for the provided url into a cookie jar (usable with http.Client) consisting of cookies passed through filter func f.
func ReadJarFilteredContext ¶
func ReadJarFilteredContext(ctx context.Context, profile, urlstr string, f func(*http.Cookie) bool) (http.CookieJar, error)
ReadJarFilteredContext reads the cookies from the provided sqlite3 file for the provided url into a cookie jar (usable with http.Client) consisting of cookies passed through filter func f.
Types ¶
This section is empty.